==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/settings/l10n/lt_LT.js <==
OC.L10N.register(
    "settings",
    {
    "Enabled" : "Įjungta",
    "Not enabled" : "Neįjungta",
    "Wrong password" : "Neteisingas slaptažodis",
    "Saved" : "Įrašyta",
    "No user supplied" : "Nepateiktas naudotojas",
    "Unable to change password" : "Nepavyksta pakeisti slaptažodžio",
    "Authentication error" : "Tapatybės nustatymo klaida",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Prašome įvesti administratoriaus atkūrimo slaptažodį, kitaip visi naudotojo duomenys bus prarasti",
    "Wrong admin recovery password. Please check the password and try again." : "Netinkamas administratoriaus atkūrimo slaptažodis. Prašome pasitikrinti ir bandyti vėl.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Vidinė pusė nepalaiko slaptažodžio keitimo, tačiau naudotojo šifravimo raktas atnaujintas sėkmingai.",
    "Group already exists." : "Grupė jau yra.",
    "Unable to add group." : "Nepavyko pridėti grupės.",
    "Unable to delete group." : "Nepavyko ištrinti grupės.",
    "Email sent" : "El. paštas išsiųstas",
    "Invalid request" : "Neteisinga užklausa",
    "Invalid mail address" : "Neteisingas pašto adresas",
    "A user with that name already exists." : "Toks naudotojas jau yra.",
    "Unable to create user." : "Nepavyko sukurti naudotojo.",
    "Your %s account was created" : "Jūsų paskyra %s sukurta",
    "Unable to delete user." : "Nepavyko ištrinti naudotojo.",
    "Settings saved" : "Nustatymai įrašyti",
    "Unable to change full name" : "Nepavyko pakeisti pilno vardo",
    "Your full name has been changed." : "Pilnas vardas pakeistas.",
    "Invalid user" : "Neteisingas naudotojas",
    "Unable to change mail address" : "Nepavyko pakeisti el. pašto adresą",
    "Email saved" : "El. paštas įrašytas",
    "Password confirmation is required" : "Reikalingas slaptažodžio patvirtinimas",
    "Couldn't remove app." : "Nepavyko pašalinti programėlės.",
    "Admins can't remove themself from the admin group" : "Administratoriai negali pašalinti savęs iš administratorių grupės",
    "Unable to add user to group %s" : "Nepavyko pridėti naudotojo į grupę %s",
    "Unable to remove user from group %s" : "Nepavyko pašalinti naudotojo iš grupės %s",
    "Couldn't update app." : "Nepavyko atnaujinti programėlės.",
    "Add trusted domain" : "Pridėti patikimą domeną",
    "Not saved" : "Neįrašyta",
    "Sending..." : "Siunčiama...",
    "Official" : "Oficiali",
    "All" : "Viskas",
    "Update to %s" : "Atnaujinti į %s",
    "Enabling app …" : "Programėlė įjungiama",
    "Error while disabling app" : "Klaida, išjungiant programėlę",
    "Disable" : "Išjungti",
    "Enable" : "Įjungti",
    "Error while enabling app" : "Klaida, įjungiant programėlę",
    "Updating...." : "Atnaujinama...",
    "Error while updating app" : "Įvyko klaida atnaujinant programą",
    "Updated" : "Atnaujinta",
    "Uninstalling ...." : "Išdiegiama...",
    "Uninstall" : "Išdiegti",
    "Approved" : "Patvirtinta",
    "Experimental" : "Eksperimentinė",
    "Disconnect" : "Atjungti",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome, skirta Android",
    "iPhone iOS" : "iPhone iOS",
    "iPad iOS" : "iPad iOS",
    "iOS Client" : "iOS klientas",
    "Android Client" : "Android klientas",
    "This session" : "Šis seansas",
    "Copy" : "Kopijuoti",
    "Copied!" : "Nukopijuota!",
    "Not supported!" : "Nepalaikoma!",
    "Valid until {date}" : "Galioja iki {date}",
    "Delete" : "Ištrinti",
    "Only visible to local users" : "Matoma tik vietiniams naudotojams",
    "Only visible to you" : "Matoma tik jums",
    "Visible to local users and to trusted servers" : "Matoma tik vietiniams naudotojams ir patikimiems serveriams",
    "Public" : "Viešai",
    "Select a profile picture" : "Pasirinkite profilio paveikslą",
    "Very weak password" : "Labai silpnas slaptažodis",
    "Weak password" : "Silpnas slaptažodis",
    "So-so password" : "Neblogas slaptažodis",
    "Good password" : "Geras slaptažodis",
    "Strong password" : "Stiprus slaptažodis",
    "Groups" : "Grupės",
    "undo" : "anuliuoti",
    "never" : "niekada",
    "Add group" : "Pridėti grupę",
    "Password successfully changed" : "Slaptažodis sėkmingai pakeistas",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Slaptažodžio pakeitimas sąlygos duomenų praradimą, kadangi šiam naudotojui nėra prieinamas duomenų atkūrimas",
    "A valid username must be provided" : "Privalo būti pateiktas tinkamas naudotojo vardas",
    "A valid password must be provided" : "Slaptažodis turi būti tinkamas",
    "__language_name__" : "Lietuvių",
    "Unlimited" : "Neribotai",
    "Personal info" : "Asmeninė informacija",
    "Sessions" : "Seansai",
    "App passwords" : "Programėlių slaptažodžiai",
    "None" : "Nieko",
    "Login" : "Prisijungti",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "El. pašto serveris",
    "Open documentation" : "Atverti dokumentaciją",
    "Encryption" : "Šifravimas",
    "Authentication required" : "Reikalinga autentikacija",
    "Server address" : "Serverio adresas",
    "Port" : "Prievadas",
    "SMTP Username" : "SMTP naudotojo vardas",
    "SMTP Password" : "SMTP slaptažodis",
    "Server-side encryption" : "Šifravimas serveryje",
    "Security & setup warnings" : "Saugos ir diegimo perspėjimai",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Trūksta PHP modulio „fileinfo“. Labai rekomenduojame įjungti šį modulį, kad gauti geriausius rezultatus nustatant mime-tipą.",
    "Cron" : "Cron",
    "Execute one task with each page loaded" : "Įvykdyti vieną užduotį su kiekvieno puslapio įkėlimu",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php yra registruotas tinklapio suplanuotų užduočių paslaugose, kad iškviesti cron.php kas 15 minučių per http.",
    "Version" : "Versija",
    "Sharing" : "Dalijimasis",
    "Allow apps to use the Share API" : "Leidžia programoms naudoti Share API",
    "Allow public uploads" : "Leisti viešus įkėlimus",
    "days" : "dienos",
    "Allow resharing" : "Leisti dalintis",
    "Tips & tricks" : "Patarimai ir gudrybės",
    "Show description …" : "Rodyti aprašą …",
    "Hide description …" : "Slėpti aprašą …",
    "This app has an update available." : "Šiai programėlei yra prieinamas atnaujinimas.",
    "Cheers!" : "Sveikinimai!",
    "Forum" : "Forumas",
    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Jūs naudojate <strong>%s</strong> iš <strong>%s</strong>",
    "Profile picture" : "Profilio paveikslas",
    "Upload new" : "Įkelti naują",
    "Remove image" : "Šalinti paveikslą",
    "png or jpg, max. 20 MB" : "png arba jpg, daugiausiai 20 MB",
    "Cancel" : "Atsisakyti",
    "Email" : "El. Paštas",
    "Your email address" : "Jūsų el. pašto adresas",
    "For password recovery and notifications" : "Skirtas slaptažodžio atkūrimui ir pranešimams",
    "Phone number" : "Telefono numeris",
    "Your phone number" : "Jūsų telefono numeris",
    "Address" : "Adresas",
    "Website" : "Svetainė",
    "Your website" : "Jūsų svetainė",
    "Twitter" : "Twitter",
    "You are member of the following groups:" : "Jūs esate šių grupių narys:",
    "Password" : "Slaptažodis",
    "Current password" : "Dabartinis slaptažodis",
    "New password" : "Naujas slaptažodis",
    "Change password" : "Pakeisti slaptažodį",
    "Language" : "Kalba",
    "Help translate" : "Padėkite išversti",
    "Get the apps to sync your files" : "Atsisiųskite programėles, kad sinchronizuotumėte savo failus",
    "Desktop client" : "Darbastalio klientas",
    "Android app" : "Android programa",
    "iOS app" : "iOS programa",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "Jeigu norite palaikyti projektą, tuomet {contributeopen}prisijunkite prie kūrimo{linkclose} arba {contributeopen}skleiskite žinią kitiems{linkclose}!",
    "Show First Run Wizard again" : "Dar kartą rodyti pirmojo paleidimo vediklį",
    "Web, desktop and mobile clients currently logged in to your account." : "Saityno, darbalaukio ir mobilieji klientai, kurie šiuo metu yra prisijungę prie jūsų paskyros.",
    "Device" : "Įrenginys",
    "Last activity" : "Paskutinė veikla",
    "Name" : "Pavadinimas",
    "App name" : "Programėlės pavadinimas",
    "Create new app password" : "Sukurti naują programėlės slaptažodį",
    "Username" : "Naudotojo vardas",
    "Done" : "Atlikta",
    "Create" : "Sukurti",
    "Admin Recovery Password" : "Administracinis atkūrimo slaptažodis",
    "Enter the recovery password in order to recover the users files during password change" : "Įveskite atkūrimo slaptažodį, kad atkurtumėte naudotojo failus keičiant slaptažodį",
    "Other" : "Kita",
    "Quota" : "Limitas",
    "change full name" : "keisti pilną vardą",
    "set new password" : "nustatyti naują slaptažodį",
    "Default" : "Numatytasis",
    "Language changed" : "Kalba pakeista",
    "Please wait...." : "Prašome palaukti...",
    "iPhone" : "iPhone",
    "Fatal issues only" : "Tik lemtingosios klaidos",
    "Log" : "Žurnalas",
    "More" : "Daugiau",
    "Less" : "Mažiau",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Žurnalo failo dydis yra daugiau nei 100 MB. Jo atsiuntimas gali šiek tiek užtrukti!",
    "Group" : "Grupė"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/settings/l10n/lt_LT.js <==
OC.L10N.register(
    "settings",
    {
    "{actor} changed your password" : "{actor} pakeitė jūsų slaptažodį",
    "You changed your password" : "Jūs pakeitėte savo slaptažodį",
    "Your password was reset by an administrator" : "Administratorius atstatė jūsų slaptažodį",
    "{actor} changed your email address" : "{actor} pakeitė jūsų el. pašto adresą",
    "Security" : "Saugumas",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Jūsų <strong>slaptažodis</strong> ar <strong>el. paštas</strong> buvo pakeisti",
    "Your apps" : "Jūsų programėlės",
    "Wrong password" : "Neteisingas slaptažodis",
    "Saved" : "Įrašyta",
    "No user supplied" : "Nepateiktas naudotojas",
    "Unable to change password" : "Nepavyksta pakeisti slaptažodžio",
    "Authentication error" : "Tapatybės nustatymo klaida",
    "Wrong admin recovery password. Please check the password and try again." : "Netinkamas administratoriaus atkūrimo slaptažodis. Prašome pasitikrinti ir bandyti vėl.",
    "A problem occurred, please check your log files (Error: %s)" : "Atsirado problema, prašome patikrinti savo žurnalo failus (Klaida: %s)",
    "Group already exists." : "Grupė jau yra.",
    "Unable to add group." : "Nepavyko pridėti grupės.",
    "Unable to delete group." : "Nepavyko ištrinti grupės.",
    "Invalid SMTP password." : "Neteisingas SMTP slaptažodis.",
    "Invalid mail address" : "Neteisingas pašto adresas",
    "A user with that name already exists." : "Toks naudotojas jau yra.",
    "Unable to create user." : "Nepavyko sukurti naudotojo.",
    "Unable to delete user." : "Nepavyko ištrinti naudotojo.",
    "Error while enabling user." : "Klaida įjungiant naudotoją.",
    "Error while disabling user." : "Klaida išjungiant naudotoją.",
    "Settings saved" : "Nustatymai įrašyti",
    "Unable to change full name" : "Nepavyko pakeisti pilno vardo",
    "Your full name has been changed." : "Pilnas vardas pakeistas.",
    "Invalid user" : "Neteisingas naudotojas",
    "Unable to change mail address" : "Nepavyko pakeisti el. pašto adresą",
    "Email saved" : "El. paštas įrašytas",
    "The new email address is %s" : "Naujasis el. pašto adresas yra %s",
    "Your username is: %s" : "Jūsų naudotojo vardas yra: %s",
    "Your %s account was created" : "Jūsų paskyra %s sukurta",
    "Password confirmation is required" : "Reikalingas slaptažodžio patvirtinimas",
    "Couldn't remove app." : "Nepavyko pašalinti programėlės.",
    "Couldn't update app." : "Nepavyko atnaujinti programėlės.",
    "Add trusted domain" : "Pridėti patikimą domeną",
    "Not saved" : "Neįrašyta",
    "Sending…" : "Siunčiama…",
    "Email sent" : "El. paštas išsiųstas",
    "Official" : "Oficiali",
    "All" : "Viskas",
    "Update to %s" : "Atnaujinti į %s",
    "Disabling app …" : "Išjungiama programėlė …",
    "Error while disabling app" : "Klaida, išjungiant programėlę",
    "Disable" : "Išjungti",
    "Enable" : "Įjungti",
    "Enabling app …" : "Programėlė įjungiama",
    "Error while enabling app" : "Klaida, įjungiant programėlę",
    "Updating...." : "Atnaujinama...",
    "Error while updating app" : "Įvyko klaida atnaujinant programą",
    "Updated" : "Atnaujinta",
    "Removing …" : "Šalinama …",
    "Remove" : "Šalinti",
    "Approved" : "Patvirtinta",
    "Experimental" : "Eksperimentinė",
    "Disconnect" : "Atjungti",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome, skirta Android",
    "iPhone iOS" : "iPhone iOS",
    "iPad iOS" : "iPad iOS",
    "iOS Client" : "iOS klientas",
    "Android Client" : "Android klientas",
    "This session" : "Šis seansas",
    "Copy" : "Kopijuoti",
    "Copied!" : "Nukopijuota!",
    "Not supported!" : "Nepalaikoma!",
    "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
    "Error while loading browser sessions and device tokens" : "Klaida, įkeliant naršyklės seansus ir įrenginio prieigos raktus",
    "Error while creating device token" : "Klaida, kuriant įrenginio prieigos raktą",
    "Error while deleting the token" : "Klaida, ištrinant prieigos raktą",
    "Valid until {date}" : "Galioja iki {date}",
    "Delete" : "Ištrinti",
    "Only visible to local users" : "Matoma tik vietiniams naudotojams",
    "Only visible to you" : "Matoma tik jums",
    "Visible to local users and to trusted servers" : "Matoma tik vietiniams naudotojams ir patikimiems serveriams",
    "Public" : "Viešai",
    "Select a profile picture" : "Pasirinkite profilio paveikslą",
    "Very weak password" : "Labai silpnas slaptažodis",
    "Weak password" : "Silpnas slaptažodis",
    "So-so password" : "Neblogas slaptažodis",
    "Good password" : "Geras slaptažodis",
    "Strong password" : "Stiprus slaptažodis",
    "Groups" : "Grupės",
    "Error creating group: {message}" : "Klaida kuriant grupę: {message}",
    "undo" : "anuliuoti",
    "never" : "niekada",
    "Add group" : "Pridėti grupę",
    "Password successfully changed" : "Slaptažodis sėkmingai pakeistas",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Slaptažodžio pakeitimas sąlygos duomenų praradimą, kadangi šiam naudotojui nėra prieinamas duomenų atkūrimas",
    "A valid username must be provided" : "Privalo būti pateiktas tinkamas naudotojo vardas",
    "A valid password must be provided" : "Slaptažodis turi būti tinkamas",
    "This app has an update available." : "Šiai programėlei yra prieinamas atnaujinimas.",
    "Documentation:" : "Dokumentacija:",
    "User documentation" : "Naudotojo dokumentacija",
    "Admin documentation" : "Administratoriaus dokumentacija",
    "Report a bug" : "Pranešti apie klaidą",
    "Show description …" : "Rodyti aprašą …",
    "Hide description …" : "Slėpti aprašą …",
    "Online documentation" : "Dokumentacija internete",
    "Forum" : "Forumas",
    "None" : "Nieko",
    "Login" : "Prisijungti",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "El. pašto serveris",
    "Open documentation" : "Atverti dokumentaciją",
    "Encryption" : "Šifravimas",
    "Authentication required" : "Reikalinga autentikacija",
    "Server address" : "Serverio adresas",
    "Port" : "Prievadas",
    "SMTP Username" : "SMTP naudotojo vardas",
    "SMTP Password" : "SMTP slaptažodis",
    "Server-side encryption" : "Šifravimas serveryje",
    "Be aware that encryption always increases the file size." : "Turėkite omenyje, kad šifravimas visada padidina failų dydį.",
    "This is the final warning: Do you really want to enable encryption?" : "Tai yra paskutinis įspėjimas: Ar tikrai norite įjungti šifravimą?",
    "Enable encryption" : "Įjungti šifravimą",
    "Select default encryption module:" : "Pasirinkite numatytąjį šifravimo modulį:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Jūs turite perkelti savo šifravimo raktus iš senojo šifravimo (ownCloud <= 8.0) į naująjį. Prašome įjungti \"Numatytąjį šifravimo modulį\" ir vykdyti \"occ encryption:migrate\"",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Jūs turite perkelti savo šifravimo raktus iš senojo šifravimo (ownCloud <= 8.0) į naująjį.",
    "Security & setup warnings" : "Saugos ir diegimo perspėjimai",
    "Execute one task with each page loaded" : "Įvykdyti vieną užduotį su kiekvieno puslapio įkėlimu",
    "Version" : "Versija",
    "Sharing" : "Dalijimasis",
    "Allow apps to use the Share API" : "Leidžia programoms naudoti Share API",
    "Allow public uploads" : "Leisti viešus įkėlimus",
    "days" : "dienos",
    "Allow resharing" : "Leisti dalintis",
    "Tips & tricks" : "Patarimai ir gudrybės",
    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Jūs naudojate <strong>%s</strong> iš <strong>%s</strong>",
    "Profile picture" : "Profilio paveikslas",
    "Upload new" : "Įkelti naują",
    "Remove image" : "Šalinti paveikslą",
    "png or jpg, max. 20 MB" : "png arba jpg, daugiausiai 20 MB",
    "Cancel" : "Atsisakyti",
    "Email" : "El. Paštas",
    "Your email address" : "Jūsų el. pašto adresas",
    "No email address set" : "Nenustatytas joks el. pašto adresas",
    "Phone number" : "Telefono numeris",
    "Your phone number" : "Jūsų telefono numeris",
    "Address" : "Adresas",
    "Website" : "Svetainė",
    "Twitter" : "Twitter",
    "You are member of the following groups:" : "Jūs esate šių grupių narys:",
    "Language" : "Kalba",
    "Help translate" : "Padėkite išversti",
    "Password" : "Slaptažodis",
    "Current password" : "Dabartinis slaptažodis",
    "New password" : "Naujas slaptažodis",
    "Change password" : "Pakeisti slaptažodį",
    "Web, desktop and mobile clients currently logged in to your account." : "Saityno, darbalaukio ir mobilieji klientai, kurie šiuo metu yra prisijungę prie jūsų paskyros.",
    "Device" : "Įrenginys",
    "Last activity" : "Paskutinė veikla",
    "App name" : "Programėlės pavadinimas",
    "Create new app password" : "Sukurti naują programėlės slaptažodį",
    "For security reasons this password will only be shown once." : "Saugumo sumetimais šis slaptažodis bus parodytas tik vieną kartą.",
    "Username" : "Naudotojo vardas",
    "Done" : "Atlikta",
    "Settings" : "Nustatymai",
    "Create" : "Sukurti",
    "Admin Recovery Password" : "Administracinis atkūrimo slaptažodis",
    "Enter the recovery password in order to recover the users files during password change" : "Įveskite atkūrimo slaptažodį, kad atkurtumėte naudotojo failus keičiant slaptažodį",
    "Unlimited" : "Neribotai",
    "Other" : "Kita",
    "Quota" : "Limitas",
    "change full name" : "keisti pilną vardą",
    "set new password" : "nustatyti naują slaptažodį",
    "Default" : "Numatytasis",
    "Enabled" : "Įjungta",
    "Not enabled" : "Neįjungta",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Prašome įvesti administratoriaus atkūrimo slaptažodį, kitaip visi naudotojo duomenys bus prarasti",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Vidinė pusė nepalaiko slaptažodžio keitimo, tačiau naudotojo šifravimo raktas atnaujintas sėkmingai.",
    "Invalid request" : "Neteisinga užklausa",
    "Admins can't remove themself from the admin group" : "Administratoriai negali pašalinti savęs iš administratorių grupės",
    "Unable to add user to group %s" : "Nepavyko pridėti naudotojo į grupę %s",
    "Unable to remove user from group %s" : "Nepavyko pašalinti naudotojo iš grupės %s",
    "Sending..." : "Siunčiama...",
    "Uninstalling ...." : "Šalinama...",
    "Error while uninstalling app" : "Klaida, šalinant programėlę",
    "Uninstall" : "Šalinti",
    "__language_name__" : "Lietuvių",
    "Personal info" : "Asmeninė informacija",
    "Sessions" : "Seansai",
    "App passwords" : "Programėlių slaptažodžiai",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Trūksta PHP modulio „fileinfo“. Labai rekomenduojame įjungti šį modulį, kad gauti geriausius rezultatus nustatant mime-tipą.",
    "Cron" : "Cron",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php yra registruotas tinklapio suplanuotų užduočių paslaugose, kad iškviesti cron.php kas 15 minučių per http.",
    "Cheers!" : "Sveikinimai!",
    "For password recovery and notifications" : "Skirtas slaptažodžio atkūrimui ir pranešimams",
    "Your website" : "Jūsų svetainė",
    "Get the apps to sync your files" : "Atsisiųskite programėles, kad sinchronizuotumėte savo failus",
    "Desktop client" : "Darbalaukio klientas",
    "Android app" : "Android programa",
    "iOS app" : "iOS programa",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "Jeigu norite palaikyti projektą, tuomet {contributeopen}prisijunkite prie kūrimo{linkclose} arba {contributeopen}skleiskite žinią kitiems{linkclose}!",
    "Show First Run Wizard again" : "Dar kartą rodyti pirmojo paleidimo vediklį",
    "Name" : "Pavadinimas",
    "Follow us on Google+!" : "Sekite mus Google+!",
    "Follow us on Twitter!" : "Sekite mus Twitter!"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");
